Documentation
¶
Overview ¶
Package unversioned has the automatically generated clients for unversioned resources.
Index ¶
- type DaemonSetInterface
- type DaemonSetNamespacer
- type DeploymentInterface
- type DeploymentNamespacer
- type ExtensionsClient
- func (c *ExtensionsClient) DaemonSets(namespace string) DaemonSetInterface
- func (c *ExtensionsClient) Deployments(namespace string) DeploymentInterface
- func (c *ExtensionsClient) HorizontalPodAutoscalers(namespace string) HorizontalPodAutoscalerInterface
- func (c *ExtensionsClient) Ingresses(namespace string) IngressInterface
- func (c *ExtensionsClient) Jobs(namespace string) JobInterface
- func (c *ExtensionsClient) ThirdPartyResources(namespace string) ThirdPartyResourceInterface
- type ExtensionsInterface
- type HorizontalPodAutoscalerInterface
- type HorizontalPodAutoscalerNamespacer
- type IngressInterface
- type IngressNamespacer
- type JobInterface
- type JobNamespacer
- type ThirdPartyResourceInterface
- type ThirdPartyResourceNamespacer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DaemonSetInterface ¶
type DaemonSetInterface interface {
Create(*extensions.DaemonSet) (*extensions.DaemonSet, error)
Update(*extensions.DaemonSet) (*extensions.DaemonSet, error)
Delete(name string, options *api.DeleteOptions) error
DeleteCollection(options *api.DeleteOptions, listOptions api.ListOptions) error
Get(name string) (*extensions.DaemonSet, error)
List(opts api.ListOptions) (*extensions.DaemonSetList, error)
Watch(opts api.ListOptions) (watch.Interface, error)
}
DaemonSetInterface has methods to work with DaemonSet resources.
type DaemonSetNamespacer ¶
type DaemonSetNamespacer interface {
DaemonSets(namespace string) DaemonSetInterface
}
DaemonSetNamespacer has methods to work with DaemonSet resources in a namespace
type DeploymentInterface ¶
type DeploymentInterface interface {
Create(*extensions.Deployment) (*extensions.Deployment, error)
Update(*extensions.Deployment) (*extensions.Deployment, error)
Delete(name string, options *api.DeleteOptions) error
DeleteCollection(options *api.DeleteOptions, listOptions api.ListOptions) error
Get(name string) (*extensions.Deployment, error)
List(opts api.ListOptions) (*extensions.DeploymentList, error)
Watch(opts api.ListOptions) (watch.Interface, error)
}
DeploymentInterface has methods to work with Deployment resources.
type DeploymentNamespacer ¶
type DeploymentNamespacer interface {
Deployments(namespace string) DeploymentInterface
}
DeploymentNamespacer has methods to work with Deployment resources in a namespace
type ExtensionsClient ¶
type ExtensionsClient struct {
*unversioned.RESTClient
}
ExtensionsClient is used to interact with features provided by the Extensions group.
func New ¶
func New(c *unversioned.RESTClient) *ExtensionsClient
New creates a new ExtensionsClient for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *unversioned.Config) (*ExtensionsClient, error)
NewForConfig creates a new ExtensionsClient for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *unversioned.Config) *ExtensionsClient
NewForConfigOrDie creates a new ExtensionsClient for the given config and panics if there is an error in the config.
func (*ExtensionsClient) DaemonSets ¶
func (c *ExtensionsClient) DaemonSets(namespace string) DaemonSetInterface
func (*ExtensionsClient) Deployments ¶
func (c *ExtensionsClient) Deployments(namespace string) DeploymentInterface
func (*ExtensionsClient) HorizontalPodAutoscalers ¶
func (c *ExtensionsClient) HorizontalPodAutoscalers(namespace string) HorizontalPodAutoscalerInterface
func (*ExtensionsClient) Ingresses ¶
func (c *ExtensionsClient) Ingresses(namespace string) IngressInterface
func (*ExtensionsClient) Jobs ¶
func (c *ExtensionsClient) Jobs(namespace string) JobInterface
func (*ExtensionsClient) ThirdPartyResources ¶
func (c *ExtensionsClient) ThirdPartyResources(namespace string) ThirdPartyResourceInterface
type ExtensionsInterface ¶
type ExtensionsInterface interface {
DaemonSetNamespacer
DeploymentNamespacer
HorizontalPodAutoscalerNamespacer
IngressNamespacer
JobNamespacer
ThirdPartyResourceNamespacer
}
type HorizontalPodAutoscalerInterface ¶
type HorizontalPodAutoscalerInterface interface {
Create(*extensions.HorizontalPodAutoscaler) (*extensions.HorizontalPodAutoscaler, error)
Update(*extensions.HorizontalPodAutoscaler) (*extensions.HorizontalPodAutoscaler, error)
Delete(name string, options *api.DeleteOptions) error
DeleteCollection(options *api.DeleteOptions, listOptions api.ListOptions) error
Get(name string) (*extensions.HorizontalPodAutoscaler, error)
List(opts api.ListOptions) (*extensions.HorizontalPodAutoscalerList, error)
Watch(opts api.ListOptions) (watch.Interface, error)
}
HorizontalPodAutoscalerInterface has methods to work with HorizontalPodAutoscaler resources.
type HorizontalPodAutoscalerNamespacer ¶
type HorizontalPodAutoscalerNamespacer interface {
HorizontalPodAutoscalers(namespace string) HorizontalPodAutoscalerInterface
}
HorizontalPodAutoscalerNamespacer has methods to work with HorizontalPodAutoscaler resources in a namespace
type IngressInterface ¶
type IngressInterface interface {
Create(*extensions.Ingress) (*extensions.Ingress, error)
Update(*extensions.Ingress) (*extensions.Ingress, error)
Delete(name string, options *api.DeleteOptions) error
DeleteCollection(options *api.DeleteOptions, listOptions api.ListOptions) error
Get(name string) (*extensions.Ingress, error)
List(opts api.ListOptions) (*extensions.IngressList, error)
Watch(opts api.ListOptions) (watch.Interface, error)
}
IngressInterface has methods to work with Ingress resources.
type IngressNamespacer ¶
type IngressNamespacer interface {
Ingresses(namespace string) IngressInterface
}
IngressNamespacer has methods to work with Ingress resources in a namespace
type JobInterface ¶
type JobInterface interface {
Create(*extensions.Job) (*extensions.Job, error)
Update(*extensions.Job) (*extensions.Job, error)
Delete(name string, options *api.DeleteOptions) error
DeleteCollection(options *api.DeleteOptions, listOptions api.ListOptions) error
Get(name string) (*extensions.Job, error)
List(opts api.ListOptions) (*extensions.JobList, error)
Watch(opts api.ListOptions) (watch.Interface, error)
}
JobInterface has methods to work with Job resources.
type JobNamespacer ¶
type JobNamespacer interface {
Jobs(namespace string) JobInterface
}
JobNamespacer has methods to work with Job resources in a namespace
type ThirdPartyResourceInterface ¶
type ThirdPartyResourceInterface interface {
Create(*extensions.ThirdPartyResource) (*extensions.ThirdPartyResource, error)
Update(*extensions.ThirdPartyResource) (*extensions.ThirdPartyResource, error)
Delete(name string, options *api.DeleteOptions) error
DeleteCollection(options *api.DeleteOptions, listOptions api.ListOptions) error
Get(name string) (*extensions.ThirdPartyResource, error)
List(opts api.ListOptions) (*extensions.ThirdPartyResourceList, error)
Watch(opts api.ListOptions) (watch.Interface, error)
}
ThirdPartyResourceInterface has methods to work with ThirdPartyResource resources.
type ThirdPartyResourceNamespacer ¶
type ThirdPartyResourceNamespacer interface {
ThirdPartyResources(namespace string) ThirdPartyResourceInterface
}
ThirdPartyResourceNamespacer has methods to work with ThirdPartyResource resources in a namespace